@@ -42,8 +42,7 @@ def test_coverage_call():
 def test_completion():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -52,5 +51,4 @@ def test_completion():
             "_TYPER_COMPLETE_TESTING": "True",
         },
     )
-    # TODO: when deprecating Click 7, remove second option
-    assert "Jonny" in result.stdout or "_files" in result.stdout
+    assert "Jonny" in result.stdout
