@@ -13,8 +13,7 @@ def test_show_completion():
             "-c",
             f"{sys.executable}  -m coverage run {mod.__file__} --show-completion",
         ],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={**os.environ, "SHELL": "/bin/bash", "_TYPER_COMPLETE_TESTING": "True"},
     )
@@ -24,7 +23,7 @@ def test_show_completion():
 def test_install_completion():
     bash_completion_path: Path = Path.home() / ".bashrc"
     text = ""
-    if bash_completion_path.is_file():  # pragma: nocover
+    if bash_completion_path.is_file():  # pragma: no cover
         text = bash_completion_path.read_text()
     result = subprocess.run(
         [
@@ -32,8 +31,7 @@ def test_install_completion():
             "-c",
             f"{sys.executable} -m coverage run {mod.__file__} --install-completion",
         ],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={**os.environ, "SHELL": "/bin/bash", "_TYPER_COMPLETE_TESTING": "True"},
     )
@@ -48,8 +46,7 @@ def test_install_completion():
 def test_completion_invalid_instruction():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -64,8 +61,7 @@ def test_completion_invalid_instruction():
 def test_completion_source_bash():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -82,8 +78,7 @@ def test_completion_source_bash():
 def test_completion_source_invalid_shell():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -97,8 +92,7 @@ def test_completion_source_invalid_shell():
 def test_completion_source_invalid_instruction():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -112,8 +106,7 @@ def test_completion_source_invalid_instruction():
 def test_completion_source_zsh():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -127,8 +120,7 @@ def test_completion_source_zsh():
 def test_completion_source_fish():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -142,8 +134,7 @@ def test_completion_source_fish():
 def test_completion_source_powershell():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -160,8 +151,7 @@ def test_completion_source_powershell():
 def test_completion_source_pwsh():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
