@@ -8,8 +8,7 @@ from docs_src.commands.help import tutorial001 as mod
 def test_completion_complete_subcommand_bash():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -25,8 +24,7 @@ def test_completion_complete_subcommand_bash():
 def test_completion_complete_subcommand_bash_invalid():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -42,8 +40,7 @@ def test_completion_complete_subcommand_bash_invalid():
 def test_completion_complete_subcommand_zsh():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -61,8 +58,7 @@ def test_completion_complete_subcommand_zsh():
 def test_completion_complete_subcommand_zsh_files():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -77,8 +73,7 @@ def test_completion_complete_subcommand_zsh_files():
 def test_completion_complete_subcommand_fish():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -97,8 +92,7 @@ def test_completion_complete_subcommand_fish():
 def test_completion_complete_subcommand_fish_should_complete():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -114,8 +108,7 @@ def test_completion_complete_subcommand_fish_should_complete():
 def test_completion_complete_subcommand_fish_should_complete_no():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -131,8 +124,7 @@ def test_completion_complete_subcommand_fish_should_complete_no():
 def test_completion_complete_subcommand_powershell():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -149,8 +141,7 @@ def test_completion_complete_subcommand_powershell():
 def test_completion_complete_subcommand_pwsh():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -167,8 +158,7 @@ def test_completion_complete_subcommand_pwsh():
 def test_completion_complete_subcommand_noshell():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
