@@ -1,15 +1,23 @@
 import os
 import subprocess
 import sys
+from unittest import mock
+
+import shellingham
+import typer
+from typer.testing import CliRunner
 
 from docs_src.commands.index import tutorial001 as mod
 
+runner = CliRunner()
+app = typer.Typer()
+app.command()(mod.main)
+
 
 def test_completion_show_no_shell():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--show-completion"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -17,11 +25,7 @@ def test_completion_show_no_shell():
             "_TYPER_COMPLETE_TEST_DISABLE_SHELL_DETECTION": "True",
         },
     )
-    # TODO: when deprecating Click 7, remove second option
-    assert (
-        "Option '--show-completion' requires an argument" in result.stderr
-        or "--show-completion option requires an argument" in result.stderr
-    )
+    assert "Option '--show-completion' requires an argument" in result.stderr
 
 
 def test_completion_show_bash():
@@ -35,8 +39,7 @@ def test_completion_show_bash():
             "--show-completion",
             "bash",
         ],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -61,8 +64,7 @@ def test_completion_source_zsh():
             "--show-completion",
             "zsh",
         ],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -84,8 +86,7 @@ def test_completion_source_fish():
             "--show-completion",
             "fish",
         ],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -107,8 +108,7 @@ def test_completion_source_powershell():
             "--show-completion",
             "powershell",
         ],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -133,8 +133,7 @@ def test_completion_source_pwsh():
             "--show-completion",
             "pwsh",
         ],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
         env={
             **os.environ,
@@ -146,3 +145,11 @@ def test_completion_source_pwsh():
         "Register-ArgumentCompleter -Native -CommandName tutorial001.py -ScriptBlock $scriptblock"
         in result.stdout
     )
+
+
+def test_completion_show_invalid_shell():
+    with mock.patch.object(
+        shellingham, "detect_shell", return_value=("xshell", "/usr/bin/xshell")
+    ):
+        result = runner.invoke(app, ["--show-completion"])
+    assert "Shell xshell not supported" in result.stdout
